import axios from 'axios';
import Api from './apis';
import { baseHostUrlApi, baseHostH2 } from '../config/config';
import storage from '@/utils/storage.plugin';
import { Toast } from 'antd-mobile';
import { getParameterByName } from '../utils/common';

export default function ajax(apiKey, options) {
  const userInfo = storage.getSS('appInfo');
  const uinfo = userInfo
    ? {
        uid: userInfo.uid,
        accessToken: userInfo.accessToken
      }
    : '';
  const option = Object.assign(
    {},
    {
      isPrefixH2: false,
      contentType: 'json',
      headers: {},
      toast: true, //是否显示toast
      loading: true //默认loading
    },
    options
  );
  let _api = getApi(apiKey, option).split('@');
  if (option.path) {
    _api[0] = _api[0] + '/' + option.path;
  }
  const data = Object.assign({}, options.data || {});
  // ENV === 'development' && (data.uid = storage.getLS('uid'));
  const contentType = option.contentType === 'json' ? 'application/json' : 'application/x-www-form-urlencoded;charset=utf-8';
  let headers = Object.assign({}, { 'Content-Type': contentType }, uinfo, option.headers);
  const axiosConfig = Object.assign(
    {},
    {
      url: _api[0],
      method: _api[1],
      headers: headers
      // withCredentials: true, // 请求时是否携带cookie  //当true时要后台也配
    }
  );

  if (_api[1].toUpperCase() === 'GET') {
    axiosConfig.params = option.data;
  } else {
    axiosConfig.data = option.contentType === 'formData' ? toFormData(data) : data;
  }

  option.loading && Toast.loading('加载中...');
  return axios(axiosConfig)
    .then(response => {
      const res = response.data;
      const _resCode = res['code'];
      option.loading && Toast.hide();
      // 返回成功
      if (_resCode === '200') {
        if (option && option.success) {
          option.success.call(this, res);
        }
      } else if (_resCode === '401') {
        Toast.info('未登录');
      } else if (res['msg']) {
        if (option.toast) {
          Toast.info(res['msg']);
        }
      } else {
        Toast.info(`${res['code']}系统异常`);
      }
      return res;
    })
    .catch(error => {
      option.loading && Toast.hide();
      if (!error.message) {
        error.message = '网络错误！';
      }
      if (option && typeof option.error === 'function') {
        option.error.call(this, error.message);
      }
      alert('error:' + error.message);
      // return reject(error);
    });
}
function toFormData(data) {
  var arr = [];
  for (var key in data) {
    arr.push(key + '=' + encodeURIComponent(data[key]));
  }
  return arr.length > 0 ? arr.join('&') : null;
}
/**
 *获取http请求路径
 * @param { api中的键值 } key
 */
export function getApi(key, option) {
  const { prefix, prefixH2 } = process.env;
  let prx = option.isPrefixH2 ? prefixH2 : prefix;
  let _api = Api[key];
  if (!/\/$/.test(prx) && !/^\//.test(_api)) {
    _api = '/' + _api;
  }
  return prx + _api;
}
